==> gazie7.30.zip: gazie/modules/humres/menu.spanish.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2020 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
/*
 --------------------------------------------------------------------------

	Spanish Translation by Dante Becerra Lagos softenglish@gmail.com

*/
$transl['humres'] = array( 'name' => "MASE Recursos Humanos",
                           'title' => "MASE Recursos Humanos",
                           'm2' => array( 1 =>array("Lista del personal","Lista del personal")
                                       ),
                           'm3' => array( 1 =>array("Nuevo colaborador","Nuevo colaborador"),
										  2 => array("Registro orario", "Registro orario")
                                       )
                         );
?>

==> gazie8.00.zip: gazie/modules/humres/menu.spanish.php <==
<?php

/*
  --------------------------------------------------------------------------
  GAzie - Gestione Azienda
  Copyright (C) 2004-2021 - Antonio De Vincentiis Montesilvano (PE)
  (http://www.devincentiis.it)
  <http://gazie.sourceforge.net>
  --------------------------------------------------------------------------
  Questo programma e` free software;   e` lecito redistribuirlo  e/o
  modificarlo secondo i  termini della Licenza Pubblica Generica GNU
  come e` pubblicata dalla Free Software Foundation; o la versione 2
  della licenza o (a propria scelta) una versione successiva.

  Questo programma  e` distribuito nella speranza  che sia utile, ma
  SENZA   ALCUNA GARANZIA; senza  neppure  la  garanzia implicita di
  NEGOZIABILITA` o di  APPLICABILITA` PER UN  PARTICOLARE SCOPO.  Si
  veda la Licenza Pubblica Generica GNU per avere maggiori dettagli.

  Ognuno dovrebbe avere   ricevuto una copia  della Licenza Pubblica
  Generica GNU insieme a   questo programma; in caso  contrario,  si
  scriva   alla   Free  Software Foundation, 51 Franklin Street,
  Fifth Floor Boston, MA 02110-1335 USA Stati Uniti.
  --------------------------------------------------------------------------
 */
/*
 --------------------------------------------------------------------------

	Spanish Translation by Dante Becerra Lagos softenglish@gmail.com

*/
$transl['humres'] = array( 'name' => "MASE Recursos Humanos",
    'title' => "MASE Recursos Humanos",
    'm2' => array(1 =>array("Lista del personal","Lista del personal"),
				  2 => array("Employee timesheet", "Employee timesheet"),
				  3 => array("Pay salary", "Pay salary"),
				  4 => array("Salary payments report", "Salary payments report")
    ),
    'm3' => array(1 =>array("Nuevo colaborador","Nuevo colaborador")
    )
);
?>
